.. _delu:

delu
====

.. currentmodule:: delu

.. automodule:: delu

.. rubric:: Tensor operations

.. autosummary::
   :nosignatures:
   :toctree: api

   to
   cat
   iter_batches

.. rubric:: Tools

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   EarlyStopping
   Timer

.. rubric:: Submodules

See the sidebar on the left.

----

.. warning::
   The API listed below is deprecated.

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   ProgressTracker
   Stream

.. autosummary::
   :nosignatures:
   :toctree: api

   collate
   concat
   improve_reproducibility

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class_just_autoclass.rst

   evaluation
